/*
 * Copyright(C) OASIS(R) 2005,2009. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */

package commonj.sdo.helper;

import java.util.Calendar;
import java.util.Date;
import java.util.Locale;

import commonj.sdo.DataObject;
import commonj.sdo.Type;
import commonj.sdo.Property;

/**
 * Data helper methods.
 */
public interface DataHelper extends org.oasisopen.sdo.helper.DataHelper
{
  
  /**
   * @deprecated There is no accepted algorithm to convert a date into a Duration so
   * use of this method is discouraged.
   * Convert from a Date to a String representation of the Duration type.
   * @param date the date
   * @return a Date to a String representation of the Duration type.
   */
  String toDuration(Date date);

  /**
   * @deprecated There is no accepted algorithm to convert a date into a Duration so
   * use of this method is discouraged.
   * Convert from a Calendar to a String representation of the Duration type.
   * @param calendar the calendar to convert
   * @return a Calendar to a String representation of the Duration type.
   */
  String toDuration(Calendar calendar);

  /**
   * Project a DataObject from another HelperContext into this HelperContext.
   * A compatible type must already be defined in this HelperContext.
   * Two types, T1 and T2, are considered compatible if their definitions are identical or differ only in the following ways:
   * <LI>	If neither T1 nor T2 is a DataType, then the implementation type (in Java, the instanceClass) may differ, or may be absent in one of the types.<BL>
   * <LI>   If both T1 and T2 are DataTypes, then they may differ as long as the implementation type (in Java, the instanceClass) is the same, and the types are compatible according to the conversion table in Chapter 16. 
   * <LI>   T1.name != T2.name or T1.aliasNames != T2.aliasNames, provided there is a matching name in the two sets of names 
   * <LI>   Corresponding properties P1.name != P2.name or P1.aliasNames != P2.aliasNames, provided there is a matching name in the two sets of names
   * <LI>	Corresponding properties P1.containment != P2.containment
   * <LI>   Corresponding properties P1.type and P2.type, and P1.type not a data type, then P2.type could be the key type of P1.type (see section on Keys)
   * </BL>
   * @param originalObject
   * @return a data object defined in the current HelperContext.
   */
  DataObject project(DataObject originalObject);

  /**
   * The default DataHelper.
   * @deprecated
   */
  DataHelper INSTANCE = SDO.getDefaultHelperContext().getDataHelper();
}
